@@ -19,11 +19,11 @@
 #define LIBPLACEBO_CONFIG_H_
 
 // Increased any time the library changes in a fundamental/major way.
-#define PL_MAJOR_VER 3
+#define PL_MAJOR_VER 4
 
 // Increased any time the API changes. (Note: Does not reset when PL_MAJOR_VER
 // is increased)
-#define PL_API_VER 104
+#define PL_API_VER 192
 
 // Increased any time a fix is made to a given API version.
 #define PL_FIX_VER (pl_fix_ver())
@@ -42,9 +42,31 @@ const char *pl_version(void);
 #define PL_HAVE_SHADERC 1
 #define PL_HAVE_VULKAN 1
 #define PL_HAVE_OPENGL 1
+#undef PL_HAVE_D3D11
 #define PL_HAVE_VK_PROC_ADDR 1
 
 // Extra compiler-specific stuff
+#if defined(_MSC_VER)
+#define PL_DEPRECATED
+#else
 #define PL_DEPRECATED __attribute__((deprecated))
+#endif
+
+// C++ compatibility
+#ifdef __cplusplus
+# define PL_STRUCT(name) struct name##_t
+# define PL_API_BEGIN extern "C" {
+# define PL_API_END }
+#else
+# define PL_STRUCT(name) struct name
+# define PL_API_BEGIN
+# define PL_API_END
+// Disable this warning because libplacebo's params macros override fields
+# pragma GCC diagnostic ignored "-Woverride-init"
+#endif
+
+// Extra helper macros
+#define PL_TOSTRING_INNER(x) #x
+#define PL_TOSTRING(x) PL_TOSTRING_INNER(x)
 
 #endif // LIBPLACEBO_CONTEXT_H_
